[![PyPI version](https://badge.fury.io/py/mist_typing.svg)](https://badge.fury.io/py/mist_typing)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat-square)](http://bioconda.github.io/recipes/mist_typing/README.html)

# MiST

MiST is a rapid, accurate and flexible (core-genome) multi-locus sequence typing (MLST) allele caller.
It provides tools to download, index, and query schemes, as well as to construct (cg)MLST-based phylogenies.

# DOCUMENTATION

The documentation is available on the [Wiki](https://github.com/BioinformaticsPlatformWIV-ISP/MiST/wiki).

# CONTACT
[Create an issue](https://github.com/BioinformaticsPlatformWIV-ISP/MiST/issues) to report bugs, propose new functions 
or ask for help.

# CITATION

Bogaerts, B., Roosens, N.H.C. & Vanneste, K. MiST: rapid, accurate and flexible (core-genome) multi-locus sequence typing (MLST) allele calling from draft genomes. BMC Genomics (2025). https://doi.org/10.1186/s12864-025-12324-z
